@@ -3,7 +3,6 @@
 /* ---------                                                           */
 /*           GTKTerm Software                                          */
 /*                      (c) Julien Schmitt                             */
-/*                      julien@jls-info.com                            */
 /*                                                                     */
 /* ------------------------------------------------------------------- */
 /*                                                                     */
@@ -21,55 +20,63 @@
 #include <gdk/gdk.h>
 #include <stdlib.h>
 
-#include "widgets.h"
-#include "serie.h"
-#include "config.h"
+#include "interface.h"
+#include "serial.h"
+#include "term_config.h"
 #include "cmdline.h"
 #include "parsecfg.h"
 #include "buffer.h"
 #include "macros.h"
 #include "auto_config.h"
-#include "gettext.h"
+#include "device_monitor.h"
+#include "user_signals.h"
+
+#include <config.h>
+#include <glib/gi18n.h>
 
 int main(int argc, char *argv[])
 {
-  gchar *message;
+	gchar *message;
 
-  config_file = g_strdup_printf("%s/.gtktermrc", getenv("HOME"));
+	config_file = g_strdup_printf("%s/.gtktermrc", getenv("HOME"));
 
-  gtk_set_locale();
-  (void)bindtextdomain(PACKAGE, LOCALEDIR);
-  (void)bind_textdomain_codeset(PACKAGE, "UTF-8");
-  (void)textdomain(PACKAGE);
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
+	textdomain(PACKAGE);
 
-  gtk_init(&argc, &argv);
+	gtk_init(&argc, &argv);
 
-  create_buffer();
- 
-  create_main_window();
-  
-  if(read_command_line(argc, argv) < 0)
-    {
-      delete_buffer();
-      exit(1);
-    }
+	create_buffer();
 
-  message = Config_port();
-  if(message == NULL)
-    message = g_strdup_printf("No open port");
+	create_main_window();
 
-  Set_Font();
-  add_shortcuts();
+	if(read_command_line(argc, argv) < 0)
+	{
+		delete_buffer();
+		exit(1);
+	}
 
-  Set_status_message(message);
+	Config_port();
+	ConfigFlags();
 
-  set_view(ASCII_VIEW);
+	message = get_port_string();
+	Set_window_title(message);
+	Set_status_message(message);
+	g_free(message);
 
-  gtk_main();
+	add_shortcuts();
 
-  delete_buffer();
+	set_view(ASCII_VIEW);
 
-  Close_port_and_remove_lockfile();
+	device_monitor_start();
 
-  return 0;
+	user_signals_catch();
+
+	gtk_main();
+
+	delete_buffer();
+
+	Close_port();
+
+	return 0;
 }
