@@ -3,7 +3,6 @@
 /* --------                                                            */
 /*           GTKTerm Software                                          */
 /*                      (c) Julien Schmitt                             */
-/*                      julien@jls-info.com                            */                      
 /*                                                                     */
 /* ------------------------------------------------------------------- */
 /*                                                                     */
@@ -18,13 +17,13 @@
 
 typedef struct
 {
-  gchar *shortcut;
-  gchar *action;
-  GClosure *closure;
+	gchar *shortcut;
+	gchar *action;
+	GClosure *closure;
 }
 macro_t;
 
-gint Config_macros(GtkWidget *, guint);
+void Config_macros(GtkAction *action, gpointer data);
 void remove_shortcuts(void);
 void add_shortcuts(void);
 void create_shortcuts(macro_t *, gint);
